@@ -16,7 +16,7 @@ When adding ``--with-id`` you'll see::
   % nosetests -v --with-id
   #1 tests.test_a ... ok
   #2 tests.test_b ... ok
-  #2 tests.test_c ... ok
+  #3 tests.test_c ... ok
 
 Then you can re-run individual tests by supplying just an id number::
 
@@ -85,9 +85,9 @@ Second::
 .. note ::
 
   If you expect to use ``--failed`` regularly, it's a good idea to always run
-  run using the ``--with-id`` option. This will ensure that an id file is
-  always created, allowing you to add ``--failed`` to the command line as soon
-  as you have failing tests. Otherwise, your first run using ``--failed`` will
+  using the ``--with-id`` option. This will ensure that an id file is always
+  created, allowing you to add ``--failed`` to the command line as soon as
+  you have failing tests. Otherwise, your first run using ``--failed`` will
   (perhaps surprisingly) run *all* tests, because there won't be an id file
   containing the record of failed tests from your previous run.
   
@@ -100,7 +100,7 @@ from nose.plugins import Plugin
 from nose.util import src, set
 
 try:
-    from pickle import dump, load
+    from cPickle import dump, load
 except ImportError:
     from pickle import dump, load
 
@@ -198,6 +198,11 @@ class TestId(Plugin):
                 self.ids, self.tests, self.failed, self.source_names,
                 self.idfile)
             fh.close()
+        except ValueError, e:
+            # load() may throw a ValueError when reading the ids file, if it
+            # was generated with a newer version of Python than we are currently
+            # running.
+            log.debug('Error loading %s : %s', self.idfile, str(e))
         except IOError:
             log.debug('IO error reading %s', self.idfile)
 
